aboutsummaryrefslogtreecommitdiff
path: root/src/include
diff options
context:
space:
mode:
authorFlorian Dold <florian@dold.me>2024-10-24 16:00:08 +0200
committerFlorian Dold <florian@dold.me>2024-10-24 16:00:12 +0200
commit0ea6f1ee4df9b9868fa32b3b25174dc63a385892 (patch)
tree4cd998d7687521d557238cd0ffcb2c996126e2ee /src/include
parent758fdf14cb081404adc3cf4bf5bb61730dbffefe (diff)
do not use varargs for external conversion
The GNUNET_OS_start_process_va is anyway just a wrapper that has to do extra malloc'ing, whereas GNUNET_OS_start_process_vap doesn't. This change is also in preparation for command splitting, as varargs don't allow programmatically constructing a variable size argument list.
Diffstat (limited to 'src/include')
-rw-r--r--src/include/taler_json_lib.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/include/taler_json_lib.h b/src/include/taler_json_lib.h
index 5e78ab44d..0e8c8fc2b 100644
--- a/src/include/taler_json_lib.h
+++ b/src/include/taler_json_lib.h
@@ -929,7 +929,7 @@ typedef void
* @param cb function to call on the result
* @param cb_cls closure for @a cb
* @param binary name of the binary to execute
* @param ... NULL-terminated list of arguments for the @a binary,
* usually starting with again the name of the binary
* @return handle to cancel the operation (and kill the helper)
*/
@@ -939,7 +939,7 @@ TALER_JSON_external_conversion_start (
TALER_JSON_JsonCallback cb,
void *cb_cls,
const char *binary,
- ...);
+ const char **argv);
/**
* Abort external conversion, killing the process and preventing
@@ -929,7 +929,7 @@ typedef void
* @param cb_cls closure for @a cb
* @param binary name of the binary to execute
- * @param ... NULL-terminated list of arguments for the @a binary,
+ * @param argv NULL-terminated list of arguments for the @a binary,
* usually starting with again the name of the binary
* @return handle to cancel the operation (and kill the helper)